Module multi_turn
spice_
framework
0.1.0
Module multi_
turn
Module Items
Functions
In crate spice_
framework
spice_framework
Module
multi_
turn
Functions

first_
turn_
with_
tools
Find the first turn index where any of the specified tools appear.
tools_
in_
range
Collect all tool names called within the specified turn range.