pub fn tools_in_range(
output: &AgentOutput,
range: &RangeInclusive<usize>,
) -> Vec<String>Expand description
Collect all tool names called within the specified turn range.
pub fn tools_in_range(
output: &AgentOutput,
range: &RangeInclusive<usize>,
) -> Vec<String>Collect all tool names called within the specified turn range.