Module multi_turn

Module multi_turn 

Functions

first_turn_with_tools
Find the first turn index where any of the specified tools appear.
tools_in_range
Collect all tool names called within the specified turn range.